Enum petgraph::data::Element [−][src]
A graph element.
A sequence of Elements, for example an iterator, is laid out as follows: Nodes are implicitly given the index of their appearance in the sequence. The edges’ source and target fields refer to these indices.
Variants
NodeA graph node.
Fields of Node
weight: N |
EdgeA graph edge.
Fields of Edge
source: usize | |
target: usize | |
weight: E |