FilterNode

Trait FilterNode 

pub trait FilterNode<N> {
    // Required method
    fn include_node(&self, node: N) -> bool;
}
A graph filter for nodes.

Required Methods

fn include_node(&self, node: N) -> bool

Return true to have the node be part of the graph

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<N, S> FilterNode<N> for &HashSet<N, S>
where HashSet<N, S>: VisitMap<N>,

Source

fn include_node(&self, n: N) -> bool

Source

impl<N, S> FilterNode<N> for HashSet<N, S>
where HashSet<N, S>: VisitMap<N>,

This filter includes the nodes that are contained in the set.

Source

fn include_node(&self, n: N) -> bool

Source

impl<N> FilterNode<N> for &FixedBitSet

Source

fn include_node(&self, n: N) -> bool

Source

impl<N> FilterNode<N> for FixedBitSet

This filter includes the nodes that are contained in the set.

Source

fn include_node(&self, n: N) -> bool

Implementors

Source

impl<F, N> FilterNode<N> for F
where F: Fn(N) -> bool,