NodeCompactIndexable

Trait NodeCompactIndexable 

pub trait NodeCompactIndexable: NodeIndexable + NodeCount { }
The graph’s NodeIds map to indices, in a range without holes.

The graph’s node identifiers correspond to exactly the indices 0..self.node_bound().

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<'a, G> NodeCompactIndexable for &'a G

Implementors