Visitable

Trait Visitable 

pub trait Visitable: GraphBase {
    type Map: VisitMap<Self::NodeId>;

    // Required methods
    fn visit_map(&self) -> Self::Map;
    fn reset_map(&self, map: &mut Self::Map);
}
A graph that can create a map that tracks the visited status of its nodes.

Required Associated Types

type Map: VisitMap<Self::NodeId>

The associated map type

Required Methods

fn visit_map(&self) -> Self::Map

Create a new visitor map

fn reset_map(&self, map: &mut Self::Map)

Reset the visitor map (and resize to new size of graph if needed)

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<'a, G> Visitable for &'a G
where G: Visitable,

Source

type Map = <G as Visitable>::Map

Source

fn visit_map(&self) -> Self::Map

Source

fn reset_map(&self, map: &mut Self::Map)

Implementors

Source

impl<'a, G> Visitable for Frozen<'a, G>
where G: Visitable,

Source

type Map = <G as Visitable>::Map

Source

impl<E, Ix> Visitable for List<E, Ix>
where Ix: IndexType,

Source

type Map = FixedBitSet

Source

impl<G, F> Visitable for EdgeFiltered<G, F>
where G: Visitable,

Source

type Map = <G as Visitable>::Map

Source

impl<G, F> Visitable for NodeFiltered<G, F>
where G: Visitable,

Source

type Map = <G as Visitable>::Map

Source

impl<G: Visitable> Visitable for Acyclic<G>

Source

type Map = <G as Visitable>::Map

Source

impl<G: Visitable> Visitable for Reversed<G>

Source

type Map = <G as Visitable>::Map

Source

impl<G> Visitable for UndirectedAdaptor<G>
where G: Visitable,

Source

type Map = <G as Visitable>::Map

Source

impl<N, E, Ty, Ix> Visitable for Csr<N, E, Ty, Ix>
where Ty: EdgeType, Ix: IndexType,

Source

type Map = FixedBitSet

Source

impl<N, E, Ty, Ix> Visitable for Graph<N, E, Ty, Ix>
where Ty: EdgeType, Ix: IndexType,

Source

type Map = FixedBitSet

Source

impl<N, E, Ty, S> Visitable for GraphMap<N, E, Ty, S>
where N: Copy + Ord + Hash, Ty: EdgeType, S: BuildHasher,

Source

type Map = HashSet<N>