Struct petgraph::adj::List [−][src]
An adjacency list with labeled edges.
Can be interpreted as a directed graph with unweighted nodes.
This is the most simple adjacency list you can imagine. Graph, in contrast,
maintains both the list of successors and predecessors for each node,
which is a different trade-off.
Allows parallel edges and self-loops.
This data structure is append-only (except for [clear]), so indices
returned at some point for a given graph will stay valid with this same
graph until it is dropped or [clear] is called.
Space consumption: O(|E|).
Implementations
impl<E, Ix: IndexType> List<E, Ix>[src]
pub fn new() -> List<E, Ix>[src]
Creates a new, empty adjacency list.
pub fn with_capacity(nodes: usize) -> List<E, Ix>[src]
Creates a new, empty adjacency list tailored for nodes nodes.
pub fn clear(&mut self)[src]
Removes all nodes and edges from the list.
pub fn edge_count(&self) -> usize[src]
Returns the number of edges in the list
Computes in O(|V|) time.
pub fn add_node(&mut self) -> NodeIndex<Ix>[src]
Adds a new node to the list. This allocates a new Vec and then should
run in amortized O(1) time.
pub fn add_node_with_capacity(&mut self, successors: usize) -> NodeIndex<Ix>[src]
Adds a new node to the list. This allocates a new Vec and then should
run in amortized O(1) time.
pub fn add_node_from_edges<I: Iterator<Item = (NodeIndex<Ix>, E)>>(
&mut self,
edges: I
) -> NodeIndex<Ix>[src]
&mut self,
edges: I
) -> NodeIndex<Ix>
Adds a new node to the list by giving its list of successors and the corresponding weigths.
pub fn add_edge(
&mut self,
a: NodeIndex<Ix>,
b: NodeIndex<Ix>,
weight: E
) -> EdgeIndex<Ix>[src]
&mut self,
a: NodeIndex<Ix>,
b: NodeIndex<Ix>,
weight: E
) -> EdgeIndex<Ix>
Add an edge from a to b to the graph, with its associated
data weight.
Return the index of the new edge.
Computes in O(1) time.
Panics if the source node does not exist.
Note: List allows adding parallel (“duplicate”) edges. If you want
to avoid this, use .update_edge(a, b, weight) instead.
pub fn edge_endpoints(
&self,
e: EdgeIndex<Ix>
) -> Option<(NodeIndex<Ix>, NodeIndex<Ix>)>[src]
&self,
e: EdgeIndex<Ix>
) -> Option<(NodeIndex<Ix>, NodeIndex<Ix>)>
Accesses the source and target of edge e
Computes in O(1)
pub fn edge_indices_from(&self, a: NodeIndex<Ix>) -> OutgoingEdgeIndices<Ix>ⓘNotable traits for OutgoingEdgeIndices<Ix>
impl<Ix> Iterator for OutgoingEdgeIndices<Ix> where
Ix: IndexType, type Item = EdgeIndex<Ix>;[src]
Notable traits for OutgoingEdgeIndices<Ix>
impl<Ix> Iterator for OutgoingEdgeIndices<Ix> where
Ix: IndexType, type Item = EdgeIndex<Ix>;pub fn contains_edge(&self, a: NodeIndex<Ix>, b: NodeIndex<Ix>) -> bool[src]
Lookups whether there is an edge from a to b.
Computes in O(e') time, where e' is the number of successors of a.
pub fn find_edge(
&self,
a: NodeIndex<Ix>,
b: NodeIndex<Ix>
) -> Option<EdgeIndex<Ix>>[src]
&self,
a: NodeIndex<Ix>,
b: NodeIndex<Ix>
) -> Option<EdgeIndex<Ix>>
Lookups whether there is an edge from a to b.
Computes in O(e') time, where e' is the number of successors of a.
pub fn node_indices(&self) -> NodeIndices<Ix>ⓘNotable traits for NodeIndices<Ix>
impl<Ix> Iterator for NodeIndices<Ix> type Item = Ix;[src]
Notable traits for NodeIndices<Ix>
impl<Ix> Iterator for NodeIndices<Ix> type Item = Ix;Returns an iterator over all node indices of the graph.
Consuming the whole iterator take O(|V|).
pub fn edge_indices(&self) -> EdgeIndices<'_, E, Ix>ⓘNotable traits for EdgeIndices<'a, E, Ix>
impl<'a, E, Ix: IndexType> Iterator for EdgeIndices<'a, E, Ix> type Item = EdgeIndex<Ix>;[src]
Notable traits for EdgeIndices<'a, E, Ix>
impl<'a, E, Ix: IndexType> Iterator for EdgeIndices<'a, E, Ix> type Item = EdgeIndex<Ix>;Returns an iterator over all edge indices of the graph.
Consuming the whole iterator take O(|V| + |E|).