Struct petgraph::graphmap::Ptr [−][src]
pub struct Ptr<'b, T: 'b>(pub &'b T);
A reference that is hashed and compared by its pointer value.
Ptr is used for certain configurations of GraphMap,
in particular in the combination where the node type for
GraphMap is something of type for example Ptr(&Cell<T>),
with the Cell<T> being TypedArena allocated.