pub trait FilterNode<N> {
// Required method
fn include_node(&self, node: N) -> bool;
}Expand description
A graph filter for nodes.
Required Methods
Sourcefn include_node(&self, node: N) -> bool
fn include_node(&self, node: N) -> bool
Return true to have the node be part of the graph
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl<N, S> FilterNode<N> for &HashSet<N, S>
impl<N, S> FilterNode<N> for &HashSet<N, S>
fn include_node(&self, n: N) -> bool
Sourceimpl<N, S> FilterNode<N> for HashSet<N, S>
This filter includes the nodes that are contained in the set.
impl<N, S> FilterNode<N> for HashSet<N, S>
This filter includes the nodes that are contained in the set.
fn include_node(&self, n: N) -> bool
Sourceimpl<N> FilterNode<N> for &FixedBitSetwhere
FixedBitSet: VisitMap<N>,
impl<N> FilterNode<N> for &FixedBitSetwhere
FixedBitSet: VisitMap<N>,
fn include_node(&self, n: N) -> bool
Sourceimpl<N> FilterNode<N> for FixedBitSetwhere
FixedBitSet: VisitMap<N>,
This filter includes the nodes that are contained in the set.
impl<N> FilterNode<N> for FixedBitSetwhere
FixedBitSet: VisitMap<N>,
This filter includes the nodes that are contained in the set.