IntoNeighborsDirected

Trait IntoNeighborsDirected 

pub trait IntoNeighborsDirected: IntoNeighbors {
    type NeighborsDirected: Iterator<Item = Self::NodeId>;

    // Required method
    fn neighbors_directed(
        self,
        n: Self::NodeId,
        d: Direction,
    ) -> Self::NeighborsDirected;
}
Access to the neighbors of each node, through incoming or outgoing edges.

Depending on the graph’s edge type, the neighbors of a given directionality are:

  • Directed, Outgoing: All targets of edges from a.
  • Directed, Incoming: All sources of edges to a.
  • Undirected: All other endpoints of edges connected to a.

Required Associated Types

Required Methods

fn neighbors_directed( self, n: Self::NodeId, d: Direction, ) -> Self::NeighborsDirected

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<'a, G> IntoNeighborsDirected for &'a G

Implementors

Source

impl<'a, 'b, G> IntoNeighborsDirected for &'b Frozen<'a, G>

Source

impl<'a, G, F> IntoNeighborsDirected for &'a EdgeFiltered<G, F>

Source

impl<'a, G, F> IntoNeighborsDirected for &'a NodeFiltered<G, F>

Source

impl<'a, N, E, Ix: IndexType> IntoNeighborsDirected for &'a Acyclic<DiGraph<N, E, Ix>>

Source

impl<'a, N, E, Ix: IndexType> IntoNeighborsDirected for &'a Acyclic<StableDiGraph<N, E, Ix>>

Source

impl<'a, N, E, Ty, S> IntoNeighborsDirected for &'a GraphMap<N, E, Ty, S>
where N: Copy + Ord + Hash + 'a, Ty: EdgeType, S: BuildHasher,

Source

impl<'a, N, E: 'a, S: BuildHasher, Null: Nullable<Wrapped = E>, Ix: IndexType> IntoNeighborsDirected for &'a MatrixGraph<N, E, S, Directed, Null, Ix>

Source

impl<'a, N, E: 'a, Ty, Ix> IntoNeighborsDirected for &'a Graph<N, E, Ty, Ix>
where Ty: EdgeType, Ix: IndexType,

Source

impl<'a, N, E: 'a, Ty, Ix> IntoNeighborsDirected for &'a StableGraph<N, E, Ty, Ix>
where Ty: EdgeType, Ix: IndexType,

Source

impl<G> IntoNeighborsDirected for Reversed<G>